@@ -52,6 +52,7 @@ public:
     CGP1W,
     CGG1_V1,
     CGG1_V2,
+    CGDN1,
     CGD1,
     CGDK2,
     CGH1,
@@ -66,8 +67,7 @@ public:
     TPMS,
     LYWSD03MMC_ATC,
     CGPR1,
-    WS02,
-    WS08,
+    THERMOBEACON,
     H5055,
     H5075,
     H5072,
@@ -93,7 +93,10 @@ public:
     BPARASITE,
     BM2,
     RDL52832,
+    ABN03,
+    ABTEMP,
     IBEACON,
+    SERVICE_DATA,
     BLE_ID_MAX
   };
 
@@ -102,8 +105,9 @@ private:
   double      value_from_hex_string(const char* data_str, int offset, int data_length, bool reverse, bool canBeNegative = true, bool isFloat = false);
   double      bf_value_from_hex_string(const char* data_str, int offset, int data_length, bool reverse, bool canBeNegative = true, bool isFloat = false);
   bool        data_index_is_valid(const char* str, size_t index, size_t len);
-  int         data_length_is_valid(size_t data_len, size_t default_min, const JsonArray& condition, int idx);
+  bool        data_length_is_valid(size_t data_len, size_t default_min, const JsonArray& condition, int *idx);
   uint8_t     getBinaryData(char ch);
+  bool        evaluateDatalength(std::string op, size_t data_len, size_t req_len);
   bool        checkPropCondition(const JsonArray& prop, const char* svc_data, const char* mfg_data);
   bool        checkDeviceMatch(const JsonArray& condition, const char* svc_data, const char* mfg_data,
                                const char* dev_name, const char* svc_uuid);
