@@ -16,15 +16,11 @@ const char* _common_TH_props = "{\"properties\":{\"tempc\":{\"unit\":\"°C\",\"n
    }
 })"""";*/
 
-const char* _common_BTH_props = "{\"properties\":{\"batt\":{\"unit\":\"%\",\"name\":\"battery\"},\"tempc\":{\"unit\":\"°C\",\"name\":\"temperature\"},\"hum\":{\"unit\":\"%\",\"name\":\"humidity\"}}}";
+const char* _common_BTH_props = "{\"properties\":{\"tempc\":{\"unit\":\"°C\",\"name\":\"temperature\"},\"hum\":{\"unit\":\"%\",\"name\":\"humidity\"},\"batt\":{\"unit\":\"%\",\"name\":\"battery\"}}}";
 /*
 R""""(
 {
    "properties":{
-      "batt":{
-         "unit":"%",
-         "name":"battery"
-      },
       "tempc":{
          "unit":"°C",
          "name":"temperature"
@@ -32,14 +28,26 @@ R""""(
       "hum":{
          "unit":"%",
          "name":"humidity"
+      },
+      "batt":{
+         "unit":"%",
+         "name":"battery"
       }
    }
 })"""";*/
 
-const char* _common_BVTH_props = "{\"properties\":{\"batt\":{\"unit\":\"%\",\"name\":\"battery\"},\"volt\":{\"unit\":\"V\",\"name\":\"voltage\"},\"tempc\":{\"unit\":\"°C\",\"name\":\"temperature\"},\"hum\":{\"unit\":\"%\",\"name\":\"humidity\"}}}";
+const char* _common_BVTH_props = "{\"properties\":{\"tempc\":{\"unit\":\"°C\",\"name\":\"temperature\"},\"hum\":{\"unit\":\"%\",\"name\":\"humidity\"},\"batt\":{\"unit\":\"%\",\"name\":\"battery\"},\"volt\":{\"unit\":\"V\",\"name\":\"voltage\"}}}";
 /*R""""(
 {
    "properties":{
+      "tempc":{
+         "unit":"°C",
+         "name":"temperature"
+      },
+      "hum":{
+         "unit":"%",
+         "name":"humidity"
+      },
       "batt":{
          "unit":"%",
          "name":"battery"
@@ -47,14 +55,6 @@ const char* _common_BVTH_props = "{\"properties\":{\"batt\":{\"unit\":\"%\",\"na
       "volt":{
          "unit":"V",
          "name":"voltage"
-      },
-      "tempc":{
-         "unit":"°C",
-         "name":"temperature"
-      },
-      "hum":{
-         "unit":"%",
-         "name":"humidity"
       }
    }
 })"""";*/
